//
//  SpikeCamera.h
//  SpikeNav
//
//  Created by Robert Bridson on 24/06/09.
//  Released into the public domain
//

#import <Cocoa/Cocoa.h>

@interface SpikeCamera: NSObject {
   // camera state
   float camera_position[3]; // in rotated coordinates, not world-space!
   float heading, pitch;
   float perspective;
   float near, far;
   float width, height, aspect;
   // stylus state (only relevant when pressed down, with exception of anchor_camz which is remembered)
   float lever_threshold;
   float lever_min;
   BOOL lever; // YES if the stylus is now in lever mode instead of rotate
   float anchor_worldspace[3]; // world-space coordinates of anchor
   float anchor_camz; // camera z coordinate of anchor
   NSPoint old_tilt; // stylus tilt at last stylus-down
   float old_heading, old_pitch; // camera angles at last stylus-down
   float old_camz; // camera z at last stylus-down
}

- (SpikeCamera*) initWithRadius: (float) radius;
- (void) prepareToRender: (NSRect) pixel_bounds withRadius: (float) radius;
- (void) renderAdditions;
- (void) mouseDown: (NSEvent*) event atPoint: (NSPoint) local_point;
- (void) mouseDragged: (NSEvent*) event atPoint: (NSPoint) local_point;
- (void) mouseUp: (NSEvent*) event atPoint: (NSPoint) local_point;
- (void) unproject: (NSPoint) base_point toWorldSpace: (float[3]) world_space andCamZ: (float*) camz;
- (void) solveCameraPositionForBasePoint: (NSPoint) base_point;

@end
