//
//  SpikeView.m
//  SpikeNav
//
//  Created by Robert Bridson on 19/06/09.
//  Released into the public domain.
//

#import "SpikeView.h"
#include <math.h>
#include <OpenGL/OpenGL.h>
#include <OpenGL/gl.h>
#include <OpenGL/glu.h>

@implementation SpikeView

- (void) awakeFromNib
{
   scene=[[AnimationScene alloc] init];
   camera=[[SpikeCamera alloc] initWithRadius: [scene radius]];
   GLint swapInterval = 1;
   CGLSetParameter (CGLGetCurrentContext(), kCGLCPSwapInterval, &swapInterval);
}

- (void) drawRect: (NSRect) dirty_bounds
{
   // figure out the view etc.
   [camera prepareToRender: [self convertRectToBase: [self bounds]] withRadius: [scene radius]];
   // draw it!
   [scene renderWithLights: NO];
   // draw anchor
   [camera renderAdditions];
   // and tell the system to display our shiny new drawing
   glFlush();
   CGLFlushDrawable(CGLGetCurrentContext());
}

- (BOOL) acceptsFirstResponder
{
   return YES;
}

- (void) mouseDown: (NSEvent*) event
{
   NSPoint event_location=[event locationInWindow];
   NSPoint local_point=[self convertPoint:event_location fromView:nil];   
   [camera mouseDown: event atPoint: local_point];
   [self setNeedsDisplay: YES];
}

- (void) mouseDragged: (NSEvent*) event
{
   NSPoint event_location=[event locationInWindow];
   NSPoint local_point=[self convertPoint:event_location fromView:nil];   
   [camera mouseDragged: event atPoint: local_point];
   [self setNeedsDisplay: YES];
}

- (void) mouseUp: (NSEvent*) event
{
   NSPoint event_location=[event locationInWindow];
   NSPoint local_point=[self convertPoint:event_location fromView:nil];   
   [camera mouseUp: event atPoint: local_point];
   [self setNeedsDisplay: YES];
}

@end
